# Installation
> `npm install --save @types/slickgrid`

# Summary
This package contains type definitions for SlickGrid (https://github.com/mleibman/SlickGrid).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/slickgrid.

### Additional Details
 * Last updated: Wed, 27 Nov 2019 00:17:23 GMT
 * Dependencies: [@types/jquery](https://npmjs.com/package/@types/jquery)
 * Global values: `Slick`

# Credits
These definitions were written by Josh Baldwin (https://github.com/jbaldwin).
